.. py:currentmodule:: rubin_sim.utils

.. _rubin_sim.utils:

===============
rubin_sim utils
===============

The rubin_sim.utils module provides basic utilities that are useful throughout rubin_sim.
These include utilities for tree generation in healpy and other healpix manipulation,
coordinate transform utilities, as well as other useful tools.


Python API
==========

* :ref:`rubin_sim.utils api`

* :ref:`search`
